@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_addr.c,v 1.5 2004/05/28 01:16:49 evertonm Exp $
+  $Id: ruli_addr.c,v 1.6 2004/06/01 18:37:15 evertonm Exp $
   */
 
 
@@ -312,3 +312,56 @@ int ruli_addr_print(FILE *out, const ruli_addr_t *addr)
 
   return -1;
 }
+
+int ruli_addr_snprint(char *buf, size_t size, const ruli_addr_t *addr)
+{
+  switch (addr->addr_family) {
+  case PF_INET:
+    return snprintf(buf, size, inet_ntoa(addr->addr.ipv4));
+
+  case PF_INET6:
+    {
+      const char *begin = (const char *) &addr->addr.ipv6;
+      const char *past_end = begin + addr->addr_size;
+      int wr = 0;
+      const char *i;
+
+      assert(sizeof(addr->addr.ipv6) == addr->addr_size);
+
+      for (i = begin; i < past_end; ++i) {
+	int j = i - begin;
+	int w;
+
+	assert(wr < size);
+
+	if (j)
+	  if (!(j % 2)) {
+	    w = snprintf(buf + wr, size - wr, ":");
+	    if (w < 0)
+	      return -1;
+	    wr += w;
+	    if (wr >= size)
+	      return wr;
+
+	    assert(wr < size);
+	  }
+
+	w = snprintf(buf + wr, size - wr, "%02X", *i);
+	if (w < 0)
+	  return -1;
+	wr += w;
+	if (wr >= size)
+	  return wr;
+
+	assert(wr < size);
+      }
+
+      return wr;
+    }
+
+  default:
+    assert(0);
+  }
+
+  return -1;
+}
