@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_parse.c,v 1.16 2004/05/24 02:43:21 evertonm Exp $
+  $Id: ruli_parse.c,v 1.17 2004/06/01 18:37:18 evertonm Exp $
   */
 
 
@@ -379,6 +379,19 @@ int ruli_parse_rr_a(struct in_addr *addr,
   return RULI_PARSE_RR_OK;
 }
 
+int ruli_parse_rr_aaaa(struct in6_addr *addr,
+		       const ruli_uint8_t *rdata, ruli_uint16_t rdlength)
+{
+  int in_addr_size = sizeof(*addr);
+
+  if (rdlength != in_addr_size)
+    return RULI_PARSE_RR_FAIL;
+
+  memcpy(addr, rdata, rdlength);
+
+  return RULI_PARSE_RR_OK;
+}
+
 int ruli_parse_rr_srv(ruli_srv_rdata_t *srv_rdata,
 		      const ruli_uint8_t *rdata, ruli_uint16_t rdlength)
 {
