@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_parse.h,v 1.11 2004/05/19 23:09:09 evertonm Exp $
+  $Id: ruli_parse.h,v 1.12 2004/06/01 18:37:29 evertonm Exp $
   */
 
 
@@ -123,6 +123,9 @@ void ruli_parse_delete(ruli_parse_t *parse);
 int ruli_parse_rr_a(struct in_addr *addr,
 		    const ruli_uint8_t *rdata, ruli_uint16_t rdlength);
 
+int ruli_parse_rr_aaaa(struct in6_addr *addr,
+		       const ruli_uint8_t *rdata, ruli_uint16_t rdlength);
+
 int ruli_parse_rr_srv(ruli_srv_rdata_t *srv_rdata,
 		      const ruli_uint8_t *rdata, ruli_uint16_t rdlength);
 
