@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: addrsolver2.c,v 1.14 2004/05/24 02:43:21 evertonm Exp $
+  $Id: addrsolver2.c,v 1.15 2004/06/03 17:34:27 evertonm Exp $
  */
 
 
@@ -151,15 +151,32 @@ static void *on_answer(ruli_res_query_t *qry, void *arg)
       if (rr->qclass != RULI_RR_CLASS_IN)
 	continue;
 
-      if (rr->type != RULI_RR_TYPE_A)
-	continue;
+      switch (rr->type) {
+      case RULI_RR_TYPE_A:
 
-      result = ruli_parse_rr_a(&addr.addr.ipv4, rr->rdata, rr->rdlength);
-      if (result)
-	continue;
+	result = ruli_parse_rr_a(&addr.addr.ipv4, rr->rdata, rr->rdlength);
+	if (result)
+	  continue;
 
-      addr.addr_family = PF_INET;
-      addr.addr_size = sizeof(addr.addr.ipv4);
+	addr.addr_family = PF_INET;
+	addr.addr_size = sizeof(addr.addr.ipv4);
+
+	break;
+
+      case RULI_RR_TYPE_AAAA:
+
+	result = ruli_parse_rr_aaaa(&addr.addr.ipv6, rr->rdata, rr->rdlength);
+	if (result)
+	  continue;
+
+	addr.addr_family = PF_INET6;
+	addr.addr_size = sizeof(addr.addr.ipv6);
+
+	break;
+
+      default:
+	continue;
+      }
 
       {
 	const int OWNER_BUFSZ = 256;
@@ -185,11 +202,9 @@ static void *on_answer(ruli_res_query_t *qry, void *arg)
 	  continue;
       }
 
-      str_len = snprintf(buf, BUFSZ, "%s %s\n", domain, inet_ntoa(addr.addr.ipv4));
-  
-      assert(str_len < BUFSZ);
-
-      printf(buf);
+      printf("%s ", domain);
+      ruli_addr_print(stdout, &addr);
+      printf("\n");
 
       ++addr_count;
     }
@@ -488,30 +503,22 @@ static void parse_servers(ruli_list_t *server_list, int serverc,
   assert(serverc >= 1);
 
   for (i = 0; i < serverc; ++i) {
-    ruli_addr_t *addr;
-
-    addr = ruli_malloc(sizeof(*addr));
+    ruli_addr_t *addr = ruli_addr_parse_new(serverv[i]);
     if (!addr) {
-      fprintf(stderr, "%s: can't allocate memory for address\n", prog_name);
-      exit(1);
-    }
-
-    if (!inet_aton(serverv[i], &addr->addr.ipv4)) {
-      fprintf(stderr, "%s: invalid IP address: %s\n", prog_name, serverv[i]);
-      ruli_free(addr);
+      fprintf(stderr, "%s: can't save address: %s\n", prog_name, serverv[i]);
       exit(1);
     }
 
 #ifdef ADDRSOLVER2_DEBUG
-    fprintf(stderr, "%s: saving server: %s\n", prog_name, inet_ntoa(addr->addr.ipv4));
+    fprintf(stderr, "%s: saving server: ", prog_name);
+    ruli_addr_print(stderr, addr);
+    fprintf(stderr, "\n");
 #endif
 
     {
       int result = ruli_list_push(server_list, addr);
       assert(!result);
     }
-    addr->addr_family = PF_INET;
-    addr->addr_size = sizeof(addr->addr.ipv4);
 
   } /* for */
 }
